xsdata package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xsdata.codegen
   xsdata.formats
   xsdata.models
   xsdata.utils

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.cli
   xsdata.exceptions
   xsdata.logger

Module contents
---------------

.. automodule:: xsdata
   :members:
   :undoc-members:
   :show-inheritance:
